% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/places.R
\name{places}
\alias{places}
\title{places}
\format{
The input format must be a data frame in a two-mode edgelist structure. \cr
Data frame can contain other variables, relevant columns will be selected in \emph{Arguments} parameters. Missing values, empty cells and repeated pairs (Element-Set) will be deleted for analysis.
}
\usage{
places(data, col.elements, col.sets)
}
\arguments{
\item{data}{The input data frame. Data must be in a two-mode edgelist structure}

\item{col.elements}{The name of the column of elements}

\item{col.sets}{The name of the column of sets}
}
\value{
The output is a list with three data frames:

\itemize{\item The original two columns data frame and the column "Places" with places labels
\item A data frame containing information about places.\cr
"PlaceNumber" contains the number of the place, ordered from the highest to the lowest number of sets \cr
"PlaceLabel" contains places labels. Labels start with \emph{P}, followed by the place number, the number of elements in place and the number of sets defining place \cr
"NbElements" contains the number of elements in the place \cr
"NbSets" contains the number of sets defining the place \cr
"PlaceDetail" contains the name of all the elements in the place and all the sets defining the place
\item The network of places in a two-mode edgelist format }
}
\description{
Execute a structural equivalence analysis in bipartite graphs
}
\details{
A place is a structurally equivalent position defined by one or more sets, containing one or more elements. Then, two or more elements share a place (so, are structurally equivalent) if they are affiliated to the same sets. \cr
A network of places is defined as a collection of places linked by sharing sets. A pair of places are linked if they are defined by at least one set in common. A network of places, as a blockmodel image, is a network of structurally equivalent positions.
}
\examples{
# Load example dataset
data(fooA)

# Compute places
Result <- places(data = fooA, col.elements = "Actors", col.sets = "Groups")
Result <- places(fooA, "Actors", "Groups")
}
\references{
Pizarro, N. (2007). Structural identity and equivalence of individuals in social networks: Beyond duality. International Sociology, 22(6), 767-792 \cr
Pizarro, N. (2000).  Regularidad relacional, redes de lugares y reproducción social. Política y Sociedad, Vol 33, 167-198 \cr
Pizarro, N. (1999).  Appartenances, places et réseaux de places: la reproduction des processus sociaux et la génération d'un espace homogène pour la définition des structures sociales. Sociologie et Societés, Vol 31(1), 143-161
}
\author{
Delio Lucena Piquero (\href{http://lereps.sciencespo-toulouse.fr/}{LEREPS} - University of Toulouse) <delio.lucena@ut-capitole.fr>
}
